import React, { ReactComponentElement } from "react";
import { InternshipFormPage, MainPage, NotFoundPage } from "@/pages/main";
import { RouteProps } from "react-router-dom";

type Route = {
    name?: string;
    content: () => ReactComponentElement<any>,
} & RouteProps;

export const routes: Route[] = [
    { name: "home", path: "/", exact: true, content: () => <MainPage /> },

    { name: "internship_proposal", path: "/internship/proposal", exact: true, content: () => <InternshipFormPage /> },

    // fallback route for 404 pages
    { path: "*", content: () => <NotFoundPage /> }
]

const routeNameMap = new Map(routes.filter(({name}) => !!name).map(({ name, path }) => [ name, path instanceof Array ? path[0] : path ])) as Map<string, string>

export function route(name: string, params: { [param: string]: string } = { }) {
    const url = routeNameMap.get(name) || "";

    return Object.entries(params).reduce((url, [name, value]) => url.replace(`:${name}`, value), url);
}
